@@ -122,16 +122,11 @@
 			}
 
 #define FILL_BUFFER(_buffer,_size)								\
-			if (Player_Paused()) {							\
-				MUTEX_LOCK (vars);						\
+			MUTEX_LOCK (vars);							\
+			if (Player_Paused_internal())						\
 				VC_SilenceBytes ((SBYTE*) (_buffer), (ULONG) (_size));		\
-				MUTEX_UNLOCK (vars);						\
-			}									\
-			else {									\
-				MUTEX_LOCK (vars);						\
-				VC_WriteBytes ((SBYTE*) (_buffer), (ULONG) ((_size)));		\
-				MUTEX_UNLOCK (vars);						\
-			}
+			else	VC_WriteBytes ((SBYTE*) (_buffer), (ULONG) (_size));		\
+			MUTEX_UNLOCK (vars);
 
 /* GLOBALS */
 #if USE_FILL_THREAD
@@ -551,7 +546,7 @@ static int OSX_Init (void)
 
 #if !USE_FILL_THREAD
 	/* get the buffer memory */
-	if ((gSoundBuffer = MikMod_malloc_aligned16(gInBufferSize)) == NULL) {
+	if ((gSoundBuffer = (unsigned char *) MikMod_amalloc(gInBufferSize)) == NULL) {
 		_mm_errno = MMERR_OUT_OF_MEMORY;
 		return 1;
 	}
@@ -564,7 +559,7 @@ static int OSX_Init (void)
 	}
 
 	for (i = 0; i < NUMBER_BACK_BUFFERS; i++) {
-		if ((gSoundBackBuffer[i] = MikMod_malloc_aligned16(gInBufferSize)) == NULL) {
+		if ((gSoundBackBuffer[i] = (unsigned char *) MikMod_amalloc(gInBufferSize)) == NULL) {
 			_mm_errno = MMERR_OUT_OF_MEMORY;
 			return 1;
 		}
@@ -618,17 +613,13 @@ static void OSX_Exit (void)
 
 #if !USE_FILL_THREAD
 	/* free up the sound buffer */
-	if (gSoundBuffer) {
-		MikMod_free_aligned16 (gSoundBuffer);
-		gSoundBuffer = NULL;
-	}
+	MikMod_afree (gSoundBuffer);
+	gSoundBuffer = NULL;
 #else
 	for ( i = 0; i < NUMBER_BACK_BUFFERS; i++ ) {
 		/* free up the back buffer */
-		if (gSoundBackBuffer[i]) {
-			MikMod_free_aligned16 (gSoundBackBuffer[i]);
-			gSoundBackBuffer[i] = NULL;
-		}
+		MikMod_afree (gSoundBackBuffer[i]);
+		gSoundBackBuffer[i] = NULL;
 	}
 #endif /* USE_FILL_THREAD */
 
