@@ -33,24 +33,26 @@ extern "C" {
 
 #include <stdarg.h>
 
-#if defined(__OS2__) || defined(__EMX__) || defined(_WIN32)
-#define strcasecmp(s,t) stricmp(s,t)
+#if defined(_MSC_VER) && !defined(__cplusplus) && !defined(HAVE_CONFIG_H)
+#define inline __inline
 #endif
 
+#include "mikmod.h"
+
 #ifndef MIKMOD_UNIX
-#if (defined(unix) || defined(__unix__) || defined(__unix) || \
-        (defined(__APPLE__) && defined(__MACH__))) && \
-   !(defined(__DJGPP__) || defined(_WIN32) || defined(__OS2__) || defined(__EMX__))
+#if (defined(unix) || defined(__unix__) || defined(__unix) || (defined(__APPLE__) && defined(__MACH__))) && \
+   !(defined(_MIKMOD_WIN32) || defined(_MIKMOD_OS2) || defined(_MIKMOD_DOS) || defined(_MIKMOD_AMIGA) || defined(macintosh))
 #define MIKMOD_UNIX 1
+#else
+#define MIKMOD_UNIX 0
 #endif
 #endif /* MIKMOD_UNIX */
 
-#include <mikmod_build.h>
-
 /*========== More type definitions */
 
 /* SLONGLONG: 64bit, signed */
-#if !defined(_WIN32) && (defined(_LP64) || defined(__arch64__) || defined(__alpha) || defined(__x64_64) || defined(__powerpc64__))
+#if !defined(_WIN32) && \
+   (defined(_LP64) || defined(__LP64__) || defined(__arch64__) || defined(__alpha) || defined(__x64_64) || defined(__powerpc64__))
 typedef long            SLONGLONG;
 #define NATIVE_64BIT_INT
 #elif defined(_WIN64) /* win64 is LLP64, not LP64  */
@@ -66,6 +68,7 @@ typedef SInt64          SLONGLONG;
 #else
 typedef long long       SLONGLONG;
 #endif
+typedef int __s64_typetest [(sizeof(SLONGLONG)==8) * 2 - 1];
 
 /* pointer-sized signed int (ssize_t/intptr_t) : */
 #if defined(_WIN64) /* win64 is LLP64, not LP64  */
@@ -74,6 +77,7 @@ typedef long long       SINTPTR_T;
 /* long should be pointer-sized for all others : */
 typedef long            SINTPTR_T;
 #endif
+typedef int __iptr_typetest [(sizeof(SINTPTR_T)==sizeof(void*)) * 2 - 1];
 
 /*========== Error handling */
 
@@ -123,9 +127,13 @@ extern MikMod_handler_t _mm_errorhandler;
 DECLARE_MUTEX(lists);
 DECLARE_MUTEX(vars);
 
+/*========== Replacement funcs */
+
+extern int _mm_strcasecmp (const char *__s1, const char *__s2);
+
 /*========== Portable file I/O */
 
-extern MREADER* _mm_new_mem_reader(const void *buffer, int len);
+extern MREADER* _mm_new_mem_reader(const void *buffer, long len);
 extern void _mm_delete_mem_reader(MREADER *reader);
 
 extern MREADER* _mm_new_file_reader(FILE* fp);
@@ -203,6 +211,8 @@ extern void _mm_write_I_ULONGS(ULONG*,int,MWRITER*);
 
 /*========== Samples */
 
+#define MAX_SAMPLE_SIZE 0x10000000 /* a sane value guaranteed to not overflow an SLONG */
+
 /* This is a handle of sorts attached to any sample registered with
    SL_RegisterSample.  Generally, this only need be used or changed by the
    loaders and drivers of mikmod. */
@@ -331,7 +341,7 @@ enum {
     UNI_LAST
 };
 
-extern UWORD unioperands[UNI_LAST];
+extern const UWORD unioperands[UNI_LAST];
 
 /* IT / S3M Extended SS effects: */
 enum {
@@ -567,9 +577,9 @@ typedef struct MLOADER {
 
 /* internal loader variables */
 extern MREADER* modreader;
-extern UWORD   finetune[16];
 extern MODULE  of;                  /* static unimod loading space */
-extern UWORD   npertab[7*OCTAVE];   /* used by the original MOD loaders */
+extern const UWORD finetune[16];
+extern const UWORD npertab[7*OCTAVE];/* used by the original MOD loaders */
 
 extern SBYTE   remap[UF_MAXCHAN];   /* for removing empty channels */
 extern UBYTE*  poslookup;           /* lookup table for pattern jumps after
@@ -621,6 +631,16 @@ extern int    Player_Init(MODULE*);
 extern void   Player_Exit(MODULE*);
 extern void   Player_HandleTick(void);
 
+/*========== UnPackers */
+
+typedef BOOL (*MUNPACKER) (struct MREADER*,
+                           void** /* unpacked data out */ ,
+                           long* /* unpacked data size */ );
+extern BOOL PP20_Unpack(MREADER*, void**, long*);
+extern BOOL MMCMP_Unpack(MREADER*, void**, long*);
+extern BOOL XPK_Unpack(MREADER*, void**, long*);
+extern BOOL S404_Unpack(MREADER*, void**, long*);
+
 /*========== Drivers */
 
 /* max. number of handles a driver has to provide. (not strict) */
@@ -825,14 +845,25 @@ static __inline __m128i mm_hiqq(const __m128i a) {
 
 #endif
 
-/* MikMod_malloc_aligned16() returns a 16 byte aligned zero-filled
+#if defined(HAVE_SSE2) || defined(HAVE_ALTIVEC)
+/* MikMod_amalloc() returns a 16 byte aligned zero-filled
    memory in SIMD-enabled builds.
- - the returned memory can be reclaimed using MikMod_free_aligned16()
-   who does check for a NULL pointer.
+ - the returned memory can be freed with MikMod_afree()
  - the returned memory CAN NOT be realloc()'ed safely.  */
-void* MikMod_malloc_aligned16(size_t);
-void MikMod_free_aligned16(void *);
-
+#ifdef __cplusplus
+extern "C" {
+#endif
+void* MikMod_amalloc(size_t);
+void MikMod_afree(void *);  /* frees if ptr != NULL */
+#ifdef __cplusplus
+}
 #endif
 
+#else /* NO SIMD */
+#define MikMod_amalloc MikMod_malloc
+#define MikMod_afree MikMod_free
+#endif
+
+#endif /* _MIKMOD_INTERNALS_H */
+
 /* ex:set ts=4: */
